@@ -1,16 +1,11 @@
 package SDLx::Controller::Interface;
 use strict;
 use warnings;
-use vars qw($VERSION $XS_VERSION @ISA);
 use Carp qw/confess/;
 use Scalar::Util 'refaddr';
 
 our @ISA = qw(Exporter DynaLoader);
 
-our $VERSION    = '2.541_10';
-our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
-
 use SDL::Internal::Loader;
 
 my %_controller;
@@ -36,8 +31,8 @@ sub attach {
 
 	Carp::confess "An SDLx::Controller is needed" unless $controller && $controller->isa('SDLx::Controller');
 
-	$_controller{ refaddr $self } = [$controller];
-	my $move = sub { $self->update( $_[2], $_[1]->dt ) };
+        $_controller{ refaddr $self } = [ $controller ];
+	my $move = sub { $self->update( $_[1], $_[0] ) };
 	$_controller{ refaddr $self }->[1] = $controller->add_move_handler($move);
 
 	if ($render) {
@@ -50,11 +45,11 @@ sub attach {
 }
 
 sub detach {
-	my ($self) = @_;
-	my $controller = $_controller{ refaddr $self };
+	my ( $self) = @_;
+        my $controller = $_controller{ refaddr $self }; 
 	return unless $controller;
-	$controller->[0]->remove_move_handler( $controller->[1] );
-	$controller->[0]->remove_show_handler( $controller->[2] );
+	$controller->[0]->remove_move_handler($controller->[1]);
+	$controller->[0]->remove_show_handler($controller->[2]);
 }
 
 internal_load_dlls(__PACKAGE__);
